@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 the xine project
+ * Copyright (C) 2000-2017 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -36,6 +36,9 @@
 #include <string.h>
 #include <stdlib.h>
 
+#define LOG_MODULE "demux_yuv4mpeg2"
+#include "group_video.h"
+
 #include <xine/xine_internal.h>
 #include <xine/xineutils.h>
 #include <xine/compat.h>
@@ -264,7 +267,7 @@ static int demux_yuv4mpeg2_send_chunk(demux_plugin_t *this_gen) {
   }
 
   while(bytes_remaining) {
-    buf_element_t *buf = this->video_fifo->buffer_pool_alloc (this->video_fifo);
+    buf_element_t *buf = this->video_fifo->buffer_pool_size_alloc (this->video_fifo, bytes_remaining);
     buf->type = BUF_VIDEO_I420;
     if( this->data_size )
       buf->extra_info->input_normpos = (int)((double) current_file_pos * 65535 / this->data_size);
@@ -433,7 +436,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
   return &this->demux_plugin;
 }
 
-static void *init_plugin (xine_t *xine, void *data) {
+void *demux_yuv4mpeg2_init_class (xine_t *xine, void *data) {
   demux_yuv4mpeg2_class_t     *this;
 
   this = calloc(1, sizeof(demux_yuv4mpeg2_class_t));
@@ -448,15 +451,3 @@ static void *init_plugin (xine_t *xine, void *data) {
   return this;
 }
 
-/*
- * exported plugin catalog entry
- */
-static const demuxer_info_t demux_info_yuv4mpeg2 = {
-  10                       /* priority */
-};
-
-const plugin_info_t xine_plugin_info[] EXPORTED = {
-  /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_DEMUX, 27, "yuv4mpeg2", XINE_VERSION_CODE, &demux_info_yuv4mpeg2, init_plugin },
-  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
-};
