@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2018 the xine project
+ * Copyright (C) 2002-2017 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -37,8 +37,8 @@
 #include "real.h"
 #include "asmrp.h"
 #include "sdpplin.h"
+#include <xine/xine_internal.h>
 #include <xine/xineutils.h>
-#include <xine/xine_buffer.h>
 #include "bswap.h"
 
 #define XOR_TABLE_LEN 37
@@ -52,7 +52,7 @@ static const unsigned char xor_table[] = {
 #define _X_BE_32C(x,y) do { *(uint32_t *)(x) = be2me_32((y)); } while(0)
 #define _X_LE_32C(x,y) do { *(uint32_t *)(x) = le2me_32((y)); } while(0)
 
-static void hash(uint8_t *field, const uint8_t *param) {
+static void hash(char *field, const char *param) {
 
   uint32_t a, b, c, d;
 
@@ -214,9 +214,9 @@ static void hash(uint8_t *field, const uint8_t *param) {
   _X_LE_32C(field+12, d);
 }
 
-static void call_hash (uint8_t *key, const uint8_t *challenge, unsigned int len) {
+static void call_hash (char *key, const char *challenge, unsigned int len) {
 
-  uint8_t *ptr1, *ptr2;
+  char *ptr1, *ptr2;
   uint32_t a, b, c, d, tmp;
 
   ptr1=(key+16);
@@ -257,10 +257,10 @@ static void call_hash (uint8_t *key, const uint8_t *challenge, unsigned int len)
   memcpy(key+b+24, challenge+c, len-c);
 }
 
-static void calc_response (uint8_t *result, uint8_t *field) {
+static void calc_response (char *result, char *field) {
 
-  uint8_t buf1[128];
-  uint8_t buf2[128];
+  char buf1[128];
+  char buf2[128];
   unsigned int i;
 
   memset (buf1, 0, 64);
@@ -285,15 +285,15 @@ static void calc_response (uint8_t *result, uint8_t *field) {
 }
 
 
-static void calc_response_string (char *result, const uint8_t *challenge) {
+static void calc_response_string (char *result, const char *challenge) {
 
-  uint8_t field[128] = {
+  char field[128] = {
     0x01, 0x23, 0x45, 0x67, 0x89, 0xAB, 0xCD, 0xEF,
     0xFE, 0xDC, 0xBA, 0x98, 0x76, 0x54, 0x32, 0x10,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
   };
-  uint8_t zres[20];
+  char zres[20];
   int  i;
 
   /* calculate response */
@@ -316,8 +316,8 @@ void real_calc_response_and_checksum (char *response, char *chksum, char *challe
 
   size_t ch_len, resp_len;
   int   i;
-  uint8_t *ptr;
-  uint8_t  buf[128] = { 0, };
+  char *ptr;
+  char  buf[128] = { 0, };
 
   /* initialize return values */
   memset(response, 0, 64);
@@ -357,7 +357,7 @@ void real_calc_response_and_checksum (char *response, char *chksum, char *challe
 
   /* calculate checksum */
   resp_len = strlen (response);
-  for (i=0; i<(int)(resp_len/4); i++)
+  for (i=0; i<resp_len/4; i++)
     chksum[i] = response[i*4];
 }
 
@@ -609,8 +609,7 @@ rmff_header_t  *real_setup_and_get_header(rtsp_t *rtsp_session, uint32_t bandwid
   char *description=NULL;
   char *session_id=NULL;
   rmff_header_t *h = NULL;
-  const char *tmp;
-  char *challenge1 = NULL;
+  char *challenge1;
   char challenge2[64];
   char checksum[34];
   char *subscribe = NULL;
@@ -620,11 +619,8 @@ rmff_header_t  *real_setup_and_get_header(rtsp_t *rtsp_session, uint32_t bandwid
   int status;
 
   /* get challenge */
-  tmp = rtsp_search_answers(rtsp_session,"RealChallenge1");
-  if (tmp) {
-    challenge1 = strdup(tmp);
-    lprintf("Challenge1: %s\n", challenge1);
-  }
+  challenge1=strdup(rtsp_search_answers(rtsp_session,"RealChallenge1"));
+  lprintf("Challenge1: %s\n", challenge1);
 
   /* request stream description */
   rtsp_schedule_field(rtsp_session, "Accept: application/sdp");
@@ -688,12 +684,10 @@ rmff_header_t  *real_setup_and_get_header(rtsp_t *rtsp_session, uint32_t bandwid
 	  h->cont->title, h->cont->copyright, h->cont->author, h->prop->num_streams);
 
   /* setup our streams */
- if (challenge1) {
   real_calc_response_and_checksum (challenge2, checksum, challenge1);
   xine_buffer_ensure_size(buf, strlen(challenge2) + strlen(checksum) + 32);
   sprintf(buf, "RealChallenge2: %s, sd=%s", challenge2, checksum);
   rtsp_schedule_field(rtsp_session, buf);
- }
   xine_buffer_ensure_size(buf, strlen(session_id) + 32);
   sprintf(buf, "If-Match: %s", session_id);
   rtsp_schedule_field(rtsp_session, buf);
