@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004, 2008 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * Copyright (C) 2004 the Unichrome project
  *
  * This file is part of xine, a free video player.
@@ -36,6 +36,7 @@
 
 #include "xxmc.h"
 #include <unistd.h>
+#include <pthread.h>
 #include "xv_common.h"
 
 
@@ -762,7 +763,7 @@ static void xxmc_dispose_context(xxmc_driver_t *driver)
 
     xprintf(driver->xine, XINE_VERBOSITY_LOG,
 	    LOG_MODULE ": Freeing up XvMC Surfaces and subpictures.\n");
-    if (driver->xvmc_palette) free(driver->xvmc_palette);
+    _x_freep(&driver->xvmc_palette);
     _x_dispose_xx44_palette( &driver->palette );
     xxmc_xvmc_destroy_subpictures( driver );
     xxmc_xvmc_destroy_surfaces( driver );
@@ -1113,7 +1114,7 @@ static void dispose_ximage (xxmc_driver_t *this,
 
   }
   else {
-    if (myimage->data) free(myimage->data);
+    _x_freep(&myimage->data);
     XFree (myimage);
   }
 
@@ -1595,6 +1596,19 @@ static void xxmc_add_recent_frame (xxmc_driver_t *this, xxmc_frame_t *frame)
   this->recent_frames[0] = frame;
 }
 
+static int xv_flush_recent_frames (xxmc_driver_t *this) {
+  int i, n = 0;
+
+  for (i = 0; i < VO_NUM_RECENT_FRAMES; i++) {
+    if (this->recent_frames[i]) {
+      this->recent_frames[i]->vo_frame.free (&this->recent_frames[i]->vo_frame);
+      this->recent_frames[i] = NULL;
+      n++;
+    }
+  }
+  return n;
+}
+
 static int xxmc_redraw_needed (vo_driver_t *this_gen)
 {
   xxmc_driver_t  *this = (xxmc_driver_t *) this_gen;
@@ -1879,6 +1893,11 @@ static int xxmc_set_property (vo_driver_t *this_gen,
   else {
     switch (property) {
 
+    case VO_PROP_DISCARD_FRAMES:
+      if (value == -1)
+        value = xv_flush_recent_frames (this);
+      break;
+
     case VO_PROP_INTERLACED:
       this->props[property].value = value;
       xprintf(this->xine, XINE_VERBOSITY_LOG,
@@ -2335,7 +2354,11 @@ static void checkXvMCCap( xxmc_driver_t *this, XvPortID xv_port)
   }
   this->xvmc_cap = (xvmc_capabilities_t *)
     xine_xmalloc(numSurf * sizeof(xvmc_capabilities_t));
-  if (NULL == this->xvmc_cap) return;
+  if (NULL == this->xvmc_cap) {
+    XVMCUNLOCKDISPLAY( this->display );
+    xvmc_context_writer_unlock( &this->xvmc_lock );
+    return;
+  }
   this->xvmc_num_cap = numSurf;
   curInfo = surfaceInfo;
   curCap = this->xvmc_cap;
@@ -2447,7 +2470,7 @@ static vo_driver_t *open_plugin (video_driver_class_t *class_gen, const void *vi
   XvAttribute          *attr;
   XvImageFormatValues  *fo;
   int                   nattr;
-  x11_visual_t         *visual = (x11_visual_t *) visual_gen;
+  const x11_visual_t   *visual = (const x11_visual_t *) visual_gen;
   XColor                dummy;
   XvImage              *myimage;
   unsigned int          adaptors;
@@ -2496,7 +2519,7 @@ static vo_driver_t *open_plugin (video_driver_class_t *class_gen, const void *vi
 				  VIDEO_DEVICE_XV_PORT_HELP,
 				  20, NULL, NULL);
   prefer_type = config->register_enum (config, "video.device.xv_preferred_method", 0,
-				       prefer_labels, VIDEO_DEVICE_XV_PREFER_TYPE_HELP,
+				       (char **)prefer_labels, VIDEO_DEVICE_XV_PREFER_TYPE_HELP,
 				       10, NULL, NULL);
 
   if (xv_port != 0) {
@@ -2667,7 +2690,7 @@ static vo_driver_t *open_plugin (video_driver_class_t *class_gen, const void *vi
 	} else if(!strcmp(name, "XV_BICUBIC")) {
 	  int xv_bicubic =
 	    config->register_enum (config, "video.device.xv_bicubic", 2,
-				   bicubic_types, VIDEO_DEVICE_XV_BICUBIC_HELP,
+				   (char **)bicubic_types, VIDEO_DEVICE_XV_BICUBIC_HELP,
 				   20, xxmc_update_XV_BICUBIC, this);
 	  config->update_num(config,"video.device.xv_bicubic",xv_bicubic);
 	}
